import Vue from "vue";
import TagIcon from "./icons/TagIcon.vue";
import { capitalize } from "vuepress-shared/lib/client";
import { pageInfoLocales } from "./../define";
export default Vue.extend({
    name: "TagInfo",
    components: { TagIcon },
    props: {
        tags: {
            type: Array,
            default: () => [],
        },
        tagPath: { type: String, default: "" },
    },
    computed: {
        items() {
            if (this.tags.length !== 0)
                return this.tags;
            const { tags, tag = tags } = this.$frontmatter;
            if (typeof tag === "string")
                return [capitalize(tag)];
            if (Array.isArray(tag))
                return tag.map((item) => capitalize(item));
            return [];
        },
        clickable() {
            return Boolean(this.tagPath);
        },
        hint() {
            return pageInfoLocales[this.$localePath].tag;
        },
    },
    methods: {
        navigate(tagName) {
            const path = this.tagPath.replace(/\$tag/g, decodeURI(tagName));
            if (this.$route.path !== path)
                void this.$router.push(path);
        },
    },
});
//# sourceMappingURL=TagInfo.js.map